@@ -1,11 +1,11 @@
 from sqlite3 import DataError
+import traceback
 import numpy as np
 import httpx
 from aiohttp_retry import ExponentialRetry, RetryClient
 
 from qiniu import put_file, put_data, Auth, etag
 from qiniu import BucketManager, build_batch_delete
-from async_cow import AsyncCow, ClientCow
 
 from hamunafs.backends.base import BackendBase
 from aiohttp_retry import ExponentialRetry, RetryClient
@@ -18,8 +18,6 @@ class Qiniu(BackendBase):
         self.domain = domain
         self.default_bucket = default_bucket
         self.bucket = BucketManager(self.auth)
-
-        self.cow = AsyncCow(cfg['key'], cfg['secret'])
     
     def get_token(self, filename):
         return self.auth.upload_token(self.default_bucket, filename)
@@ -35,12 +33,18 @@ class Qiniu(BackendBase):
             else:
                 _bucket = bucket
             b_name = '{}_{}'.format(_bucket, bucket_name)
+            print('acquiring upload token....')
             token = self.auth.upload_token(self.default_bucket, b_name)
+            print('upload token acquired -> {}'.format(token))
+            print('uploading...')
             ret, info = put_file(token, b_name, file)
             if ret is not None:
+                print('upload success.')
                 return True, '{}/{}'.format(_bucket, bucket_name)
+            print('upload failed.')
             return False, '上传失败'
         except Exception as e:
+            traceback.print_exc()
             return False, str(e)
     
     async def put_async(self, file, bucket, bucket_name, tmp=True):
