@@ -10,17 +10,16 @@ import asyncio
 import time
 import os
 import argparse
-from hamunafs.utils.mqtt import MQTTClient
 
 from hamunafs.utils.nsqmanager import MQManager
 from hamunafs.sqlite import DB
 
 def get_opts():
     parser = argparse.ArgumentParser()
-    parser.add_argument('--host', type=str, default='raspbian')
+    parser.add_argument('--host', type=str, default='127.0.0.1')
     parser.add_argument('--port', type=str, default='9000')
     parser.add_argument('--acs-key', type=str, default='hmcz')
-    parser.add_argument('--acs-secret', type=str, default='hmcz1234')
+    parser.add_argument('--acs-secret', type=str, default='1987yang')
     parser.add_argument('--location', type=str, default='brick1')
     parser.add_argument('--root-path', type=str, default='../hmfs_data')
     parser.add_argument('--api-host', type=str, default='backend.ai.hamuna.club')
@@ -31,10 +30,6 @@ def get_opts():
     parser.add_argument('--redis-port', type=int, default=6379)
     parser.add_argument('--redis-pass', type=str, default='1987yang')
     parser.add_argument('--redis-db', type=int, default=2)
-    parser.add_argument('--mqtt-host', type=str, default='kafka.ai.hamuna.club')
-    parser.add_argument('--mqtt-port', type=int, default=1883)
-    parser.add_argument('--mqtt-user', type=str, default='opush')
-    parser.add_argument('--mqtt-pass', type=str, default='innovation')
 
     opt = parser.parse_args()
     return opt
@@ -60,17 +55,12 @@ broker_cfg = {
     'http_port': opt.broker_http_port
 }
 
-def on_mqtt_message(client, userdata, msg):
-    if msg.topic == 'fs_backend_update':
-        client.update()
     
 minio = MinioAgent('{}:{}'.format(opt.host, opt.port), opt.acs_key, opt.acs_secret, secure=False, location=opt.location)
 
 cache_engine = CacheManager(opt.redis_host, opt.redis_pass, opt.redis_port, opt.redis_db, local_cache=None)
 
-mqtt_client = MQTTClient('fs_server', opt.mqtt_user, opt.mqtt_pass).connect(opt.mqtt_host, opt.mqtt_port)
-mqtt_client.subscribe('fs_backend_update', 2)
-mqtt_client.register_on_message_handler(on_mqtt_message)
+
 
 patch_frame_config(
     NSQD_TCP_ADDRESSES=['{}:{}'.format(
@@ -81,7 +71,7 @@ patch_frame_config(
 
 hmfs_client = Client.get_client(opt.api_host, cache_engine.client, None)
 
-@task_deco('fs_put', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ)
+@task_deco('fs_put', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ, specify_async_loop=asyncio.get_event_loop())
 async def file_transfer_put(url, bucket, bucket_name, ttl):
     key = 'file_transfer_put_{}_{}'.format(bucket, bucket_name)
     if await cache_engine.get_cache_async(key, return_obj=False) is not None:
@@ -90,7 +80,7 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
     with cache_engine.lock(key, ttl=30) as lock:
         if lock:
             try:
-                if await cache_engine.get_cache_async(key, return_obj=False) is not None:
+                if cache_engine.get_cache(key, return_obj=False) is not None:
                     return
                 
                 file_path = os.path.join(cache_path, '{}_{}'.format(bucket, bucket_name))
@@ -136,12 +126,12 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                     }, expired=60)
 
 
-@task_deco('fs_get', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ)
+@task_deco('fs_get', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ, specify_async_loop=asyncio.get_event_loop())
 async def file_transfer_get(bucket, bucket_name, refresh='no'):
     try:
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
         if refresh == 'no':
-            remote_state = await cache_engine.get_cache_async(task_id)
+            remote_state = cache_engine.get_cache(task_id)
             if remote_state is not None:
                 ret = remote_state['ret']
                 if ret:
@@ -149,7 +139,7 @@ async def file_transfer_get(bucket, bucket_name, refresh='no'):
                     return
 
         with cache_engine.lock(task_id) as lock:
-            remote_state = await cache_engine.get_cache_async(task_id)
+            remote_state = cache_engine.get_cache(task_id)
             if remote_state is not None:
                 ret = remote_state['ret']
                 if ret:
@@ -201,7 +191,7 @@ async def file_transfer_get(bucket, bucket_name, refresh='no'):
 #             print('ok')
             
 async def ttl_cleanup():
-    rows = sqlite_db.select('select id, bucket, bucket_name from ttl_files where expired >= ?', (time.time(),))
+    rows = sqlite_db.select('select id, bucket, bucket_name from ttl_files where expired < ?', (time.time(),))
     affected_records = 0
     if rows is not None:
         for r in rows:
